@@ -40,6 +40,7 @@ class SwaggerGenerator(object):
         self._add_binary_types(api, app)
         self._add_route_paths(api, app)
         self._add_resource_policy(api, rest_api)
+        self._add_vpc_endpoint(api, rest_api)
         return api
 
     def _add_resource_policy(self, api, rest_api):
@@ -47,6 +48,13 @@ class SwaggerGenerator(object):
         if rest_api and rest_api.policy:
             api['x-amazon-apigateway-policy'] = rest_api.policy.document
 
+    def _add_vpc_endpoint(self, api, rest_api):
+        # type: (Dict[str, Any], Optional[RestAPI]) -> None
+        if rest_api and rest_api.vpce_ids:
+            api['x-amazon-apigateway-endpoint-configuration'] = {
+                "vpcEndpointIds": rest_api.vpce_ids
+            }
+
     def _add_binary_types(self, api, app):
         # type: (Dict[str, Any], Chalice) -> None
         api['x-amazon-apigateway-binary-media-types'] = app.api.binary_types
@@ -83,7 +91,7 @@ class SwaggerGenerator(object):
             config = {
                 'in': 'header',
                 'type': 'apiKey',
-                'name': 'Authorization',
+                'name': auth_config.header,
                 'x-amazon-apigateway-authtype': 'custom'
             }
             api_gateway_authorizer = {
